Browser Pedals

## Usage:

### Control any video in a web browser with foot pedals - pause/play or jump back - even when the web browser is not in focus.

#### How to start controlling a video/audio with pedals:

Navigate to any Web site containing a video/audio (or to a local video/audio file: Firefox - "Alt" key, Chrome and Edge - "Ctrl+O" key).

To start controlling a video/audio with pedals, click "Play" button on the video with the mouse at least once.

To stop controlling the video/audio with pedals, click "Pause" button on the video with the mouse (not with pedals).
After that, you can start controlling any other video on the site by clicking it's "Play" button.

You may have to wait for about a minute before the program starts controlling the video, or click "Play" button on the video with the mouse several times.

#### How to control the video/audio with pedals:

To pause/play the video, press right pedal (or other pedal of your choice).

To jump back in the video, press left pedal (or other pedal of your choice).

## Как пользоваться:

### Управлять просмотром любого видео в веб-браузере с использованием ножных педалей - приостановить/продолжить или вернуться назад - даже когда веб-браузер находится не в фокусе.

#### Как начать управлять видео/аудио при помощи педалей:

Перейдите на любой веб-сайт, содержащий видео/аудио (или видео/аудио файл на компьютере: Firefox - клавиша "Alt", Chrome или Edge - клавиша "Ctrl+O").

Чтобы начать управлять видео/аудио при помощи педалей, кликните мышью кнопку "Воспроизведение" на видео хотя бы один раз.

Чтобы прекратить управлять данным видео/аудио при помощи педалей, кликните мышью кнопку "Пауза" на видео (не педалями).
После этого вы сможете начать управлять любым другим видео на сайте, кликнув мышью на его кнопке "Воспроизведение".

Иногда нужно подождать примерно минуту, пока программа начнет управлять выбранным видео, или кликнуть мышью кнопку "Воспроизведение" на видео несколько раз.

#### Как управлять видео/аудио при помощи педалей:

Чтобы приостановить/продолжить просмотр видео, нажмите правую педаль (или другую назначенную вами педаль).

Чтобы отмотать видео назад, нажмите левую педаль (или другую назначенную вами педаль).

## Editable options:

Application's editable data directory:

`application_data_directory`

## Редактируемые опции:

Директория редактируемых данных программы:

`application_data_directory`

### Change the program's options:

The following text file contains several options which users can edit to change the way the program behaves:

`options_text_file`

Available options:

browser: By default, the program opens Firefox browser. To use another browser, change the value of the browser option in the options file correspondingly. So far, the program was tested with Firefox, Chrome, and Edge browsers.

user_interface: By default, the program uses web browser as graphical user interface during pedals recognition. To use command line for pedals recognition, change the value of the user_interface option in the options file from "browser" to "command_line".

jump_back_sec: By default, pressing the "jump back" pedal rewinds the video 5 seconds back. To use another time jump, change the value of the jump_back_sec option in the options file correspondingly. It may be any number, possibly with a fractional part.

### Browser data:

When this program opens a web browser, it uses a browser user's profile which is different from default profile used when the browser is opened standard way. All browser data (including user preferences, browser cache, history, bookmarks, installed extensions, etc.) used by web browsers when they are opened by this program are stored in the following location. If a profile here is deleted, a clean profile will be created instead:

`browser_profiles_directory`

### Изменение опций программы:

Следующий текстовый файл содержит ряд опций, которые пользователь может менять, чтобы корректировать поведение программы:

`options_text_file`

Имеющиеся опции:

browser: По умолчанию программа открывает браузер Firefox. Чтобы использовать другой браузер, в файле опций соответствующим образом поменяйте значение value опции browser. На данный момент программа тестировалась с браузерами Firefox, Chrome, и Edge.

user_interface: По умолчанию программа использует веб-браузер в качестве графического пользовательского интерфейса при распознавании педалей. Чтобы использовать командную строку для распознавания педалей, в файле опций поменяйте значение value опции user_interface с "browser" на "command_line".

jump_back_sec: По умолчанию при нажатии педали "возврат назад" видео отматывается назад на 5 секунд. Чтобы использовать другой временной скачок, в файле опций соответствующим образом поменяйте значение value опции jump_back_sec. Это может быть любое число, возможно с дробной частью.

### Данные браузера:

Когда данная программа открывает веб-браузер, используется пользовательский профиль отличный от профиля, используемого по умолчанию при открытии браузера обычным образом. Все данные браузера (включая пользовательские настройки, кэш браузера, историю, закладки, установленные расширения, и т.п.), используемые веб-браузерами, когда они открываются данной программой, хранятся в следующей директории. Если профиль здесь удалить, вместо него будет создан чистый профиль:

`browser_profiles_directory`

### Install the Web Driver (optional):

The program comes with a pre-installed Web Driver for Firefox browser, so if you want to use Firefox it will work out of the box. However, if you want to use another browser like Chrome or Edge, you have to install corresponding Web Driver manually as described below. Also, in case of Chrome or Edge you will have to periodically upgrade the Web Driver to match the current version of automatically upgraded Chrome or Edge browser.

Install the Web Driver for the browser you want to use. The download links are on the site:

Download a Web Driver

Important:For all browsers except Firefox, the version of Web Driver file should match the current version of your browser.

Open the downloaded archive and extract the Web Driver executable. For Firefox browser the Web Driver file name is usually "geckodriver". For Chrome browser the Web Driver file name is usually "chromedriver". For Edge browser the Web Driver file name is usually "msedgedriver.exe".

Place the Web Driver file into the corresponding sub-directory of the program's data directory:

`web_driver_directory`

### Установка веб-драйвера (опционно):

Программа поставляется с предустановленным веб-драйвером для браузера Firefox, поэтому если вы хотите использовать Firefox, он будет работать без каких-либо дополнительных действий. Однако, если вы хотите использовать другой браузер, например Chrome или Edge, вы должны установить соответствующий веб-драйвер вручную, как описано ниже. К тому же, в случае использования Chrome или Edge вы должны будете периодически обновлять веб-драйвер, чтобы его версия совпадала с текущей версией автоматически обновляемого браузера Chrome или Edge.

Установите веб-драйвер для браузера, который вы хотите использовать. Ссылки для загрузки приведены на сайте:

Скачать веб-драйвер

Важно:Для всех браузеров, кроме Firefox, версия файла веб-драйвера должна совпадать с текущей версией вашего браузера.

Откройте скачанный архив и извлеките файл веб-драйвера. Веб-драйвер для браузера Firefox обычно имеет имя "geckodriver". Веб-драйвер для браузера Chrome обычно имеет имя "chromedriver". Веб-драйвер для браузера Edge обычно имеет имя "msedgedriver.exe".

Поместите файл веб-драйвера в соответствующую поддиректорию в директории данных программы:

`web_driver_directory`

### Automatic pedals detection:

Currently, the program supports just one specific type of pedals out of the box - the "Thrustmaster wheel" foot pedals (Thrustmaster 360 SPIDER PC).

If other pedals are used, the program will attempt to recognize them automatically. Just plug the pedals into the PC, run the program, and follow the instructions on the screen. If the pedals are recognized successfully, the information is saved to the file "auto_detected_pedals.txt", and next time the program is run the new pedals will be recognized automatically:

`auto_detected_pedals_file`

Users who use pedals which where successfully recognized by the program, can send the above file to the program's developer so new versions of the program could support these pedals out of the box:

Email

Site

Currently supported pedal roles are "Pause/Play pedal" and "Jump Back pedal". User can assign any role to any pedal, can use both pedals or just one. This is done automatically by running the program and following the instructions on the screen.

(Technically, the auto_detected_pedals.txt file can also be edited manually.)

### Автоматическое распознавание педалей:

В настоящее время программа поддерживает только один конкретный вид педалей, с которыми она работает без дополнительной настройки - это ножные педали "Thrustmaster wheel" (Thrustmaster 360 SPIDER PC).

Если используются другие педали, программа попытается распознать их автоматически. Просто подключите педали к компьютеру, запустите программу и следуйте инструкциям на экране. Если педали будут удачно распознаны, информация будет сохранена в файле "auto_detected_pedals.txt", и при следующем запуске программы новые педали будут распознаны автоматически:

`auto_detected_pedals_file`

Пользователи, использующие педали, успешно распознанные программой, могут отправить вышеуказанный файл разработчику, чтобы последующие версии программы работали с данными педалями без дополнительной настройки:

Email

Сайт

В настоящее время поддерживаются следующие роли педалей: "Педаль Пауза/Воспроизведение" и "Педаль Возврата назад". Любой педали можно назначить любую из этих ролей. Можно использовать обе педали, или только одну. Все это делается автоматически путем запуска программы и следования инструкциям на экране.

(Технически, файл auto_detected_pedals.txt можно также редактировать вручную.)

### Running the program:

If the program was installed using PIP:

`python3 -m pip install --no-cache-dir browserpedals`

then a shortcut ("BrowserPedals" icon) was automatically created on the Desktop and in the Applications menu. In this case the program can be launched using this shortcut, or by right-clicking the video file which we want to open and selecting "BrowserPedals" program from the drop-down menu. Technically, the program "browserpedals.py" or its submodules "usepedals.py" and "detectpedals.py" can also be run as Python scripts from command line:

`python3 browserpedals.py`

### Запуск программы:

Если программа устанавливалась с использованием PIP:

`python3 -m pip install --no-cache-dir browserpedals`

тогда на рабочем столе и в меню приложений для нее был автоматически создан ярлык "BrowserPedals". В этом случае программу можно запустить, используя этот ярлык, или щелкнув правой кнопкой мыши на том видео-файле, который мы хотим открыть, и в выпадающем меню выбрав программу "BrowserPedals". Технически, программу "browserpedals.py" и ее подмодули "usepedals.py" и "detectpedals.py" можно также запустить из командной строки как Python-скрипты:

`python3 browserpedals.py`

### Changing the appearance of the user interface:

The program uses web browser as graphical user interface. The way the interface elements look can be changed by editing the following CSS file:

`ui_appearance_css_file`

### Изменение внешнего вида пользовательского интерфейса:

В качестве графического пользовательского интерфейса программа использует веб-браузер. То, как выглядят элементы этого интерфейса, можно менять, редактируя следующий CSS-файл:

`ui_appearance_css_file`